HashTagText class

Show decorated tagged text only to be shown

decoratedStyle is textStyle of tagged text. basicStyle is textStyle of others. onTap is called when a tagged text is tapped.

Inheritance

Constructors

HashTagText({Key? key, required String text, required TextStyle basicStyle, required TextStyle decoratedStyle, bool decorateAtSign = false, bool decorateCashtag = false, List<String>? customPrefixes, dynamic onTap(String)?, TextAlign textAlign = TextAlign.start, TextDirection? textDirection, bool softWrap = true, TextOverflow overflow = TextOverflow.clip, double textScaleFactor = 1.0, TextScaler? textScaler, int? maxLines, Locale? locale, StrutStyle? strutStyle, TextWidthBasis textWidthBasis = TextWidthBasis.parent, TextHeightBehavior? textHeightBehavior})
Creates a HashTagText widget.

Properties

basicStyle → TextStyle
The TextStyle applied to normal untagged text.
final
customPrefixes → List<String>?
Optional list of custom prefix symbols to decorate.
final
decorateAtSign → bool
Whether to decorate words starting with @ (mentions).
final
decorateCashtag → bool
Whether to decorate words starting with $ (cashtags).
final
decoratedStyle → TextStyle
The TextStyle applied to hashtags, mentions, or cashtags.
final
hashCode → int
The hash code for this object.
no setterinherited
key → Key?
Controls how one widget replaces another widget in the tree.
finalinherited
locale → Locale?
Used to select a font when the same Unicode character can be rendered differently.
final
maxLines → int?
An optional maximum number of lines for the text to span.
final
onTap → dynamic Function(String)?
Callback when a tag is tapped.
final
overflow → TextOverflow
How visual overflow should be handled.
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
softWrap → bool
Whether the text should break at soft line breaks.
final
strutStyle → StrutStyle?
The strut style to use. Strut style defines the strut, which sets minimum vertical layout metrics.
final
text → String
The text to display and decorate.
final
textAlign → TextAlign
How the text should be aligned horizontally.
final
textDirection → TextDirection?
The directionality of the text.
final
textHeightBehavior → TextHeightBehavior?
final
textScaleFactor → double
Deprecated text scale factor. Use textScaler instead.
final
textScaler → TextScaler?
The modern TextScaler used to scale text.
final
textWidthBasis → TextWidthBasis
Defines how to measure the width of the rendered text.
final

Methods

build(BuildContext context) → Widget
Describes the part of the user interface represented by this widget.
override
createElement() → StatelessElement
Creates a StatelessElement to manage this widget's location in the tree.
inherited
debugDescribeChildren() → List<DiagnosticsNode>
Returns a list of DiagnosticsNode objects describing this node's children.
inherited
debugFillProperties(DiagnosticPropertiesBuilder properties) → void
Add additional properties associated with the node.
inherited
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toDiagnosticsNode({String? name, DiagnosticsTreeStyle? style}) → DiagnosticsNode
Returns a debug representation of the object that is used by debugging tools and by DiagnosticsNode.toStringDeep.
inherited
toString({DiagnosticLevel minLevel = DiagnosticLevel.info}) → String
A string representation of this object.
inherited
toStringDeep({String prefixLineOne = '', String? prefixOtherLines, DiagnosticLevel minLevel = DiagnosticLevel.debug, int wrapWidth = 65}) → String
Returns a string representation of this node and its descendants.
inherited
toStringShallow({String joiner = ', ', DiagnosticLevel minLevel = DiagnosticLevel.debug}) → String
Returns a one-line detailed description of the object.
inherited
toStringShort() → String
A short, textual description of this widget.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited